summaryrefslogtreecommitdiffstats
path: root/src/H5Lpublic.h
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2007-10-30 22:56:15 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2007-10-30 22:56:15 (GMT)
commitb969dce6e5625dd9d9f9cc42717a1b2027fdeeb1 (patch)
treeae2f2b4b6b417831b35f14c4e12e4bcc7971b636 /src/H5Lpublic.h
parentc136b81140106231e471b334bc5248611cec04e6 (diff)
downloadhdf5-b969dce6e5625dd9d9f9cc42717a1b2027fdeeb1.zip
hdf5-b969dce6e5625dd9d9f9cc42717a1b2027fdeeb1.tar.gz
hdf5-b969dce6e5625dd9d9f9cc42717a1b2027fdeeb1.tar.bz2
[svn-r14224] Description:
Change H5Literate -> H5Literate_by_name and add simpler form of H5Literate, to bring this routine into alignment with the other new API routines. Tested on: FreeBSD/32 6.2 (duty) in debug mode FreeBSD/64 6.2 (liberty) w/C++ & FORTRAN, in debug mode Linux/32 2.6 (kagiso) w/PGI compilers, w/C++ & FORTRAN, w/threadsafe, in debug mode Linux/64-amd64 2.6 (smirom) w/default API=1.6.x, w/C++ & FORTRAN, in production mode Linux/64-ia64 2.6 (cobalt) w/Intel compilers, w/C++ & FORTRAN, in production mode Solaris/32 2.10 (linew) w/deprecated symbols disabled, w/C++ & FORTRAN, w/szip filter, in production mode Mac OS X/32 10.4.10 (amazon) in debug mode
Diffstat (limited to 'src/H5Lpublic.h')
-rw-r--r--src/H5Lpublic.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/H5Lpublic.h b/src/H5Lpublic.h
index 863155e..9a85900 100644
--- a/src/H5Lpublic.h
+++ b/src/H5Lpublic.h
@@ -127,7 +127,7 @@ typedef struct {
H5L_query_func_t query_func; /* Callback for queries */
} H5L_class_t;
/* Prototype for H5Literate() operator */
typedef herr_t (*H5L_iterate_t)(hid_t group, const char *name, const H5L_info_t *info,
void *op_data);
@@ -167,7 +167,9 @@ H5_DLL herr_t H5Lget_info_by_idx(hid_t loc_id, const char *group_name,
H5_DLL ssize_t H5Lget_name_by_idx(hid_t loc_id, const char *group_name,
H5_index_t idx_type, H5_iter_order_t order, hsize_t n,
char *name /*out*/, size_t size, hid_t lapl_id);
-H5_DLL herr_t H5Literate(hid_t loc_id, const char *group_name,
+H5_DLL herr_t H5Literate(hid_t grp_id, H5_index_t idx_type,
+ H5_iter_order_t order, hsize_t *idx, H5L_iterate_t op, void *op_data);
+H5_DLL herr_t H5Literate_by_name(hid_t loc_id, const char *group_name,
H5_index_t idx_type, H5_iter_order_t order, hsize_t *idx,
H5L_iterate_t op, void *op_data, hid_t lapl_id);
@@ -127,7 +127,7 @@ typedef struct {
H5L_query_func_t query_func; /* Callback for queries */
} H5L_class_t;
-/* Prototype for H5Literate() operator */
+/* Prototype for H5Literate/H5Literate_by_name() operator */
typedef herr_t (*H5L_iterate_t)(hid_t group, const char *name, const H5L_info_t *info,
void *op_data);